@@ -1110,7 +1110,7 @@ brasero_burn_dialog_disable_joliet_cb (BraseroBurn *burn,
 	return brasero_burn_dialog_continue_question (dialog,
 	                                              _("Do you want to continue with full Windows compatibility disabled?"),
 	                                              _("Some files don't have a suitable name for a fully Windows-compatible CD."),
-	                                              _("_Continue"));
+	                                              _("C_ontinue"));
 }
 
 static void
@@ -2561,8 +2561,6 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 
 	gtk_window_set_default_size (GTK_WINDOW (obj), 500, 0);
 
-	gtk_dialog_set_has_separator (GTK_DIALOG (obj), FALSE);
-
 	priv->tray = brasero_tray_icon_new ();
 	g_signal_connect (priv->tray,
 			  "cancel",
@@ -2616,7 +2614,7 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 }
 
 static void
-brasero_burn_dialog_destroy (GtkObject * object)
+brasero_burn_dialog_destroy (GtkWidget * object)
 {
 	BraseroBurnDialogPrivate *priv;
 
@@ -2627,8 +2625,8 @@ brasero_burn_dialog_destroy (GtkObject * object)
 		priv->burn = NULL;
 	}
 
-	if (GTK_OBJECT_CLASS (brasero_burn_dialog_parent_class)->destroy)
-		GTK_OBJECT_CLASS (brasero_burn_dialog_parent_class)->destroy (object);
+	if (GTK_WIDGET_CLASS (brasero_burn_dialog_parent_class)->destroy)
+		GTK_WIDGET_CLASS (brasero_burn_dialog_parent_class)->destroy (object);
 }
 
 static void
@@ -2691,13 +2689,12 @@ static void
 brasero_burn_dialog_class_init (BraseroBurnDialogClass * klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
 	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (BraseroBurnDialogPrivate));
 
 	object_class->finalize = brasero_burn_dialog_finalize;
-	gtk_object_class->destroy = brasero_burn_dialog_destroy;
+	widget_class->destroy = brasero_burn_dialog_destroy;
 	widget_class->delete_event = brasero_burn_dialog_delete;
 }
 
